/* rygel-test-plugin.c generated by valac 0.14.0, the Vala compiler
 * generated from rygel-test-plugin.vala, do not modify */

/*
 * Copyright (C) 2008 Zeeshan Ali (Khattak) <zeeshanak@gnome.org>.
 * Copyright (C) 2008 Nokia Corporation.
 *
 * Author: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
 *                               <zeeshan.ali@nokia.com>
 *
 * This file is part of Rygel.
 *
 * Rygel is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Rygel is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include <rygel.h>
#include <stdlib.h>
#include <string.h>


#define RYGEL_TEST_TYPE_PLUGIN (rygel_test_plugin_get_type ())
#define RYGEL_TEST_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TEST_TYPE_PLUGIN, RygelTestPlugin))
#define RYGEL_TEST_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TEST_TYPE_PLUGIN, RygelTestPluginClass))
#define RYGEL_TEST_IS_PLUGIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TEST_TYPE_PLUGIN))
#define RYGEL_TEST_IS_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TEST_TYPE_PLUGIN))
#define RYGEL_TEST_PLUGIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TEST_TYPE_PLUGIN, RygelTestPluginClass))

typedef struct _RygelTestPlugin RygelTestPlugin;
typedef struct _RygelTestPluginClass RygelTestPluginClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _RygelTestPluginPrivate RygelTestPluginPrivate;

#define RYGEL_TEST_TYPE_ROOT_CONTAINER (rygel_test_root_container_get_type ())
#define RYGEL_TEST_ROOT_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), RYGEL_TEST_TYPE_ROOT_CONTAINER, RygelTestRootContainer))
#define RYGEL_TEST_ROOT_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), RYGEL_TEST_TYPE_ROOT_CONTAINER, RygelTestRootContainerClass))
#define RYGEL_TEST_IS_ROOT_CONTAINER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), RYGEL_TEST_TYPE_ROOT_CONTAINER))
#define RYGEL_TEST_IS_ROOT_CONTAINER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), RYGEL_TEST_TYPE_ROOT_CONTAINER))
#define RYGEL_TEST_ROOT_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), RYGEL_TEST_TYPE_ROOT_CONTAINER, RygelTestRootContainerClass))

typedef struct _RygelTestRootContainer RygelTestRootContainer;
typedef struct _RygelTestRootContainerClass RygelTestRootContainerClass;

struct _RygelTestPlugin {
	RygelMediaServerPlugin parent_instance;
	RygelTestPluginPrivate * priv;
};

struct _RygelTestPluginClass {
	RygelMediaServerPluginClass parent_class;
};


static gpointer rygel_test_plugin_parent_class = NULL;

void module_init (RygelPluginLoader* loader);
#define RYGEL_TEST_PLUGIN_NAME "Test"
RygelTestPlugin* rygel_test_plugin_new (void);
RygelTestPlugin* rygel_test_plugin_construct (GType object_type);
GType rygel_test_plugin_get_type (void) G_GNUC_CONST;
enum  {
	RYGEL_TEST_PLUGIN_DUMMY_PROPERTY
};
RygelTestRootContainer* rygel_test_root_container_new (const gchar* title);
RygelTestRootContainer* rygel_test_root_container_construct (GType object_type, const gchar* title);
GType rygel_test_root_container_get_type (void) G_GNUC_CONST;


void module_init (RygelPluginLoader* loader) {
	RygelPluginLoader* _tmp0_;
	gboolean _tmp1_ = FALSE;
	RygelTestPlugin* _tmp2_;
	RygelTestPlugin* plugin;
	RygelPluginLoader* _tmp3_;
	RygelTestPlugin* _tmp4_;
#line 28 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	g_return_if_fail (loader != NULL);
#line 29 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp0_ = loader;
#line 29 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp1_ = rygel_plugin_loader_plugin_disabled (_tmp0_, RYGEL_TEST_PLUGIN_NAME);
#line 29 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	if (_tmp1_) {
#line 30 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
		g_message ("rygel-test-plugin.vala:30: Plugin '%s' disabled by user, ignoring..", RYGEL_TEST_PLUGIN_NAME);
#line 33 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
		return;
#line 102 "rygel-test-plugin.c"
	}
#line 36 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp2_ = rygel_test_plugin_new ();
#line 36 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	plugin = _tmp2_;
#line 38 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp3_ = loader;
#line 38 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp4_ = plugin;
#line 38 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	rygel_plugin_loader_add_plugin (_tmp3_, (RygelPlugin*) _tmp4_);
#line 28 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_g_object_unref0 (plugin);
#line 116 "rygel-test-plugin.c"
}


RygelTestPlugin* rygel_test_plugin_construct (GType object_type) {
	RygelTestPlugin * self = NULL;
	RygelTestRootContainer* _tmp0_;
	RygelTestRootContainer* root_container;
#line 45 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_tmp0_ = rygel_test_root_container_new ("Test Streams");
#line 45 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	root_container = _tmp0_;
#line 47 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	self = (RygelTestPlugin*) rygel_media_server_plugin_construct (object_type, (RygelMediaContainer*) root_container, RYGEL_TEST_PLUGIN_NAME, NULL);
#line 44 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	_g_object_unref0 (root_container);
#line 44 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	return self;
#line 134 "rygel-test-plugin.c"
}


RygelTestPlugin* rygel_test_plugin_new (void) {
#line 44 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	return rygel_test_plugin_construct (RYGEL_TEST_TYPE_PLUGIN);
#line 141 "rygel-test-plugin.c"
}


static void rygel_test_plugin_class_init (RygelTestPluginClass * klass) {
#line 41 "/home/jens/Source/rygel/src/plugins/test/rygel-test-plugin.vala"
	rygel_test_plugin_parent_class = g_type_class_peek_parent (klass);
#line 148 "rygel-test-plugin.c"
}


static void rygel_test_plugin_instance_init (RygelTestPlugin * self) {
}


GType rygel_test_plugin_get_type (void) {
	static volatile gsize rygel_test_plugin_type_id__volatile = 0;
	if (g_once_init_enter (&rygel_test_plugin_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (RygelTestPluginClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) rygel_test_plugin_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (RygelTestPlugin), 0, (GInstanceInitFunc) rygel_test_plugin_instance_init, NULL };
		GType rygel_test_plugin_type_id;
		rygel_test_plugin_type_id = g_type_register_static (RYGEL_TYPE_MEDIA_SERVER_PLUGIN, "RygelTestPlugin", &g_define_type_info, 0);
		g_once_init_leave (&rygel_test_plugin_type_id__volatile, rygel_test_plugin_type_id);
	}
	return rygel_test_plugin_type_id__volatile;
}



